Hi,
This is odd...
There is no casting required when a double is returned from a function as it's returned in an FP register anyway. The overhead of passing a double to a function is having to 'push' 8 bytes instead of 4.
In other words, I don't think its a float/double thing but some other weird issue. The '^2.0' is likely to be slow - perhaps I've optimized this in BP to a multiply but not in Max...
And both are of course running with debug disabled?
This is odd...
There is no casting required when a double is returned from a function as it's returned in an FP register anyway. The overhead of passing a double to a function is having to 'push' 8 bytes instead of 4.
In other words, I don't think its a float/double thing but some other weird issue. The '^2.0' is likely to be slow - perhaps I've optimized this in BP to a multiply but not in Max...
And both are of course running with debug disabled?